==> haskell-config-schema-1.3.0.0-228.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-config-schema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 config-schema
version:              1.3.0.0
visibility:           public
id:                   config-schema-1.3.0.0-18cPQKDZtdiBM7eLOJ4ikS
key:                  config-schema-1.3.0.0-18cPQKDZtdiBM7eLOJ4ikS
license:              ISC
copyright:            Eric Mertens 2017
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-schema
synopsis:             Schema definitions for the config-value package
description:
    This package makes it possible to define schemas for use when
    loading configuration files using the config-value format.
    These schemas can be used to process a configuration file into
    a Haskell value or to automatically generate documentation for
    the file format.

category:             Language
abi:                  19fb9662654cbed8f33c740669128738
exposed:              True
exposed-modules:
    Config.Schema Config.Schema.Docs Config.Schema.Load
    Config.Schema.Load.Error Config.Schema.Spec Config.Schema.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/config-schema-1.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/config-schema-1.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/config-schema-1.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-schema
hs-libraries:         HSconfig-schema-1.3.0.0-18cPQKDZtdiBM7eLOJ4ikS
depends:
    base-4.18.2.1 config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU
    containers-0.6.7 free-5.2-3fckYVSYEwRA3sQVkSQiQV
    kan-extensions-5.2.7-EnBT78A8Pv5AQm9RtrTyNw pretty-1.1.3.6
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-config-schema/html/config-schema.haddock

haddock-html:         /usr/share/doc/haskell-config-schema/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-schema-1.3.0.0-229-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-config-schema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 config-schema
version:              1.3.0.0
visibility:           public
id:                   config-schema-1.3.0.0-KaToPnRJDn51YwFTmE8dwj
key:                  config-schema-1.3.0.0-KaToPnRJDn51YwFTmE8dwj
license:              ISC
copyright:            Eric Mertens 2017
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-schema
synopsis:             Schema definitions for the config-value package
description:
    This package makes it possible to define schemas for use when
    loading configuration files using the config-value format.
    These schemas can be used to process a configuration file into
    a Haskell value or to automatically generate documentation for
    the file format.

category:             Language
abi:                  d43ed5577a75f060e7b6769f8d842cff
exposed:              True
exposed-modules:
    Config.Schema Config.Schema.Docs Config.Schema.Load
    Config.Schema.Load.Error Config.Schema.Spec Config.Schema.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/config-schema-1.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/config-schema-1.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/config-schema-1.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-schema
hs-libraries:         HSconfig-schema-1.3.0.0-KaToPnRJDn51YwFTmE8dwj
depends:
    base-4.18.2.1 config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU
    containers-0.6.7 free-5.2-CP2SAI6deNWCXG1eD5QmMc
    kan-extensions-5.2.7-CxNd8hhXH2ZC3bz6YYdu9A pretty-1.1.3.6
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-config-schema/html/config-schema.haddock

haddock-html:         /usr/share/doc/haskell-config-schema/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
